<?php

namespace DynamicOOO\PluginUtilsV2\AdminPages\Pages;

if (!\defined('ABSPATH')) {
    exit;
    // Exit if accessed directly.
}
class LicensePage extends \DynamicOOO\PluginUtilsV2\AdminPages\Pages\Base
{
    /**
     * Render page content
     *
     * @return void
     */
    protected function render_content()
    {
        if ('POST' === $_SERVER['REQUEST_METHOD'] && (!isset($_POST[$this->plugin_utils_manager->get_config('prefix') . '-settings-page']) || !wp_verify_nonce($_POST[$this->plugin_utils_manager->get_config('prefix') . '-settings-page'], $this->plugin_utils_manager->get_config('prefix') . '-settings-page'))) {
            wp_die(esc_html__('Nonce verification error.', 'dynamic-content-for-elementor'));
        }
        $license_system = $this->plugin_utils_manager->license;
        if (isset($_POST['license_key'])) {
            if ($_POST['license_activated']) {
                list($success, $msg) = $license_system->deactivate_license();
                if (!$success) {
                    $this->plugin_utils_manager->admin_pages->admin_notices->error($msg);
                } else {
                    $msg = esc_html__('License key successfully deactivated for this site', 'dynamic-content-for-elementor');
                    $this->plugin_utils_manager->admin_pages->admin_notices->success($msg);
                }
            } else {
                $license_key = $_POST['license_key'];
                list($success, $msg) = $license_system->activate_new_license_key($license_key);
                if (!$success) {
                    $this->plugin_utils_manager->admin_pages->admin_notices->error($msg);
                } else {
                    $msg = esc_html__('License key successfully activated for this site', 'dynamic-content-for-elementor');
                    $this->plugin_utils_manager->admin_pages->admin_notices->success($msg);
                }
            }
        } else {
            $license_system->refresh_and_repair_license_status();
        }
        if (isset($_POST['beta_status'])) {
            if (isset($_POST['enable_beta'])) {
                $license_system->activate_beta_releases();
            } else {
                $license_system->deactivate_beta_releases();
            }
        }
        if ($license_system->domain_mismatch_check()) {
            $this->plugin_utils_manager->admin_pages->admin_notices->warning(esc_html__('License Mismatch. Your license key doesn\'t match your current domain. This is likely due to a change in the domain URL. You can reactivate your license now. Remember to deactivate the one for the old domain from your license area on Dynamic.ooo\'s site', 'dynamic-content-for-elementor'));
        }
        $license_key = $license_system->get_license_key();
        $is_license_active = $license_system->is_license_active();
        $license_domain = get_option($this->plugin_utils_manager->get_config('prefix') . '_license_domain');
        ?>
		<div class="ooo-content-wrapper">
			<div class="ooo-license-tab">
				<h2 class="ooo-license-status">
					<?php 
        esc_html_e('License Status', 'dynamic-content-for-elementor');
        ?>: 
					<?php 
        if ($is_license_active) {
            ?>
						<span class="ooo-status-active"><?php 
            esc_html_e('Active', 'dynamic-content-for-elementor');
            ?></span>
					<?php 
        } else {
            ?>
						<span class="ooo-status-inactive"><?php 
            esc_html_e('Not Active', 'dynamic-content-for-elementor');
            ?></span>
					<?php 
        }
        ?>
				</h2>

				<form action="" method="post" class="ooo-license-key">
					<?php 
        wp_nonce_field($this->plugin_utils_manager->get_config('prefix') . '-settings-page', $this->plugin_utils_manager->get_config('prefix') . '-settings-page');
        ?>
					<input type="text" 
						   autocomplete="new-password" 
						   autocorrect="off"
						   autocapitalize="off"
						   spellcheck="false"
						   style="-webkit-text-security: disc; text-security: disc; width: 100%; max-width: 300px;"
						   name="license_key" 
						   value="<?php 
        echo esc_attr($license_key);
        ?>" 
						   placeholder="<?php 
        esc_attr_e('Insert License Key', 'dynamic-content-for-elementor');
        ?>" 
						   id="license_key">
					<input type="hidden" name="license_activated" value="<?php 
        echo esc_attr($is_license_active);
        ?>">
					<?php 
        if ($is_license_active) {
            submit_button(esc_html__('Deactivate', 'dynamic-content-for-elementor'), 'cancel', 'submit', \false);
        } else {
            submit_button(esc_html__('Save key and activate', 'dynamic-content-for-elementor'), 'primary', 'submit', \false);
        }
        ?>
				</form>

				<?php 
        if ($is_license_active) {
            ?>
					<?php 
            if ($license_domain && $license_domain !== $license_system->get_current_domain()) {
                ?>
						<p><strong class="ooo-text-warning">
							<?php 
                esc_html_e('Your license is valid but there is something wrong: license mismatch.', 'dynamic-content-for-elementor');
                ?>
						</strong></p>
						<p><?php 
                esc_html_e('Your license key doesn\'t match your current domain. This is most likely due to a change in the domain URL. Please deactivate the license and reactivate it', 'dynamic-content-for-elementor');
                ?></p>
					<?php 
            } else {
                ?>
						<p><strong class="ooo-status-active">
							<?php 
                \printf(esc_html__('Your license ending in "%1$s" is valid and active.', 'dynamic-content-for-elementor'), '<strong>' . esc_html($license_system->get_license_key_last_4_digits()) . '</strong>');
                ?>
						</strong></p>
					<?php 
            }
            ?>
				<?php 
        } else {
            ?>
					<div class="ooo-license-get-it-now">
						<p><?php 
            esc_html_e('Enter your license to keep the plugin updated, obtaining new features, future compatibility, increased stability, security, and technical support.', 'dynamic-content-for-elementor');
            ?></p>
						<p>
							<?php 
            esc_html_e('You still don\'t have one?', 'dynamic-content-for-elementor');
            ?> 
							<a href="<?php 
            echo esc_url($this->plugin_utils_manager->get_config('pricing_url'));
            ?>" class="button button-small" target="_blank">
								<?php 
            esc_html_e('Get it now!', 'dynamic-content-for-elementor');
            ?>
							</a>
						</p>
					</div>
				<?php 
        }
        ?>
			</div>

			<?php 
        if ($is_license_active) {
            ?>
				<?php 
            if ($this->plugin_utils_manager->get_config('supports_beta')) {
                $beta_enabled = get_option($this->plugin_utils_manager->get_config('prefix') . '_beta');
                ?>
				<div class="ooo-license-tab ooo-beta-section">
					<h3><?php 
                esc_html_e('Beta Release', 'dynamic-content-for-elementor');
                ?></h3>
					<form action="" method="post" class="ooo-beta-form">
						<?php 
                wp_nonce_field($this->plugin_utils_manager->get_config('prefix') . '-settings-page', $this->plugin_utils_manager->get_config('prefix') . '-settings-page');
                ?>
						<label>
							<input type="checkbox" name="enable_beta" value="1" <?php 
                checked($beta_enabled);
                ?>>
							<?php 
                esc_html_e('Enable beta releases. Important: Do not use in production, consider this only for staging sites.', 'dynamic-content-for-elementor');
                ?>
						</label>
						<input type="hidden" name="beta_status" value="1">
						<?php 
                submit_button(esc_html__('Save my preference', 'dynamic-content-for-elementor'), 'secondary', 'submit', \false);
                ?>
					</form>
				</div>
				<?php 
            }
            ?>

				<?php 
            if ($this->plugin_utils_manager->get_config('supports_rollback')) {
                ?>
				<div class="ooo-license-tab ooo-rollback-section">
					<h3><?php 
                esc_html_e('Rollback Version', 'dynamic-content-for-elementor');
                ?></h3>
					<?php 
                $rollback_versions = $this->plugin_utils_manager->rollback->get_rollback_versions();
                $current_version = $this->plugin_utils_manager->get_config('version');
                ?>
					<h4><?php 
                \printf(esc_html__('Your current version: %s', 'dynamic-content-for-elementor'), $current_version);
                ?></h4>
					<p>
						<?php 
                \printf(esc_html__('Experiencing an issue with %1$s version %2$s? Rollback to a previous version before the issue appeared.', 'dynamic-content-for-elementor'), $this->plugin_utils_manager->get_config('product_name'), $current_version);
                ?>
					</p>

					<?php 
                if (!empty($rollback_versions)) {
                    ?>
						<form id="ooo-rollback-form" class="ooo-rollback-form">
							<?php 
                    wp_nonce_field($this->plugin_utils_manager->get_config('prefix') . '_plugin_rollback', 'rollback_nonce');
                    ?>
							<select name="version">
								<?php 
                    foreach ($rollback_versions as $version) {
                        ?>
									<option value="<?php 
                        echo esc_attr($version);
                        ?>">
										<?php 
                        echo esc_html($version);
                        ?>
									</option>
								<?php 
                    }
                    ?>
							</select>
							<?php 
                    submit_button(esc_html__('Rollback now', 'dynamic-content-for-elementor'), 'secondary', 'submit', \false);
                    ?>
							<span class="spinner" style="float: none; margin: 0 0 0 5px;"></span>
						</form>
						<p class="description">
							<?php 
                    esc_html_e('Warning: Please backup your site and database before making the rollback.', 'dynamic-content-for-elementor');
                    ?>
						</p>
					<?php 
                } else {
                    ?>
						<p><?php 
                    esc_html_e('No versions available for rollback.', 'dynamic-content-for-elementor');
                    ?></p>
					<?php 
                }
                ?>
				</div>
				<?php 
            }
            ?>
			<?php 
        }
        ?>
		</div>
		<script>
		jQuery(document).ready(function($) {
			$('#ooo-rollback-form').on('submit', function(e) {
				e.preventDefault();
				
				if (!confirm('<?php 
        echo esc_js(__('Are you sure you want to rollback?', 'dynamic-content-for-elementor'));
        ?>')) {
					return;
				}
				
				var $form = $(this);
				var $spinner = $form.find('.spinner');
				var $submit = $form.find('button[type="submit"]');
				
				$spinner.addClass('is-active');
				$submit.prop('disabled', true);
				
				$.ajax({
					url: ajaxurl,
					type: 'POST',
					data: {
						action: '<?php 
        echo esc_js($this->plugin_utils_manager->get_config('prefix'));
        ?>_rollback_plugin',
						version: $form.find('select[name="version"]').val(),
						nonce: $form.find('[name="rollback_nonce"]').val()
					},
					success: function(response) {
						if (response.success) {
							alert(response.data);
							location.reload();
						} else {
							alert('Error: ' + (response.data || 'Unknown error'));
						}
					},
					error: function(xhr, status, error) {
						var errorMessage;
						try {
							var response = JSON.parse(xhr.responseText);
							errorMessage = response.message || response.data || xhr.responseText;
						} catch(e) {
							errorMessage = xhr.responseText || error || 'Unknown error';
						}
						alert('Error: ' + errorMessage);
						console.error('Full error details:', {
							status: status,
							error: error,
							xhr: xhr.responseText
						});
					},
					complete: function() {
						$spinner.removeClass('is-active');
						$submit.prop('disabled', false);
					}
				});
			});
		});
		</script>
		<?php 
    }
}
