<?php

namespace DynamicOOO\PluginUtilsV2;

class Manager
{
    /**
     * @var Manager|null
     */
    protected static $instance = null;
    /**
     * @var array<string,mixed>
     */
    protected $config = [];
    /**
     * @var Rollback
     */
    public $rollback;
    /**
     * @var License
     */
    public $license;
    /**
     * @var Cron
     */
    public $cron;
    /**
     * @var WpCli
     */
    public $wpcli;
    /**
     * @var UpdateChecker
     */
    public $update_checker;
    /**
     * @var AdminPages\Manager
     */
    public $admin_pages;
    /**
     * @var Api
     */
    public $api;
    /**
     * @var Assets\Manager
     */
    public $assets;
    /**
     * @param array<string,mixed> $config
     */
    public function __construct($config)
    {
        \spl_autoload_register([$this, 'autoload']);
        $this->set_config($config);
        $this->license = new \DynamicOOO\PluginUtilsV2\License($this);
        if (!$this->get_config('delay_init')) {
            $this->init();
        }
    }
    /**
     * @param LicenseInterface|null $license_override
     */
    public function init($license_override = null)
    {
        $this->admin_pages = new \DynamicOOO\PluginUtilsV2\AdminPages\Manager($this);
        $this->license->init();
        $this->api = new \DynamicOOO\PluginUtilsV2\Api($this);
        $this->rollback = new \DynamicOOO\PluginUtilsV2\Rollback($this);
        $this->cron = new \DynamicOOO\PluginUtilsV2\Cron($this);
        if (\defined('WP_CLI') && WP_CLI) {
            new \DynamicOOO\PluginUtilsV2\WpCli($this);
        }
        if ($license_override) {
            $this->license = $license_override;
        }
        $this->update_checker = new \DynamicOOO\PluginUtilsV2\UpdateChecker($this);
        $this->assets = new \DynamicOOO\PluginUtilsV2\Assets\Manager($this);
        new \DynamicOOO\PluginUtilsV2\PluginPage($this);
    }
    public function autoload($search_class)
    {
        if (0 !== \strpos($search_class, 'DynamicOOO\\PluginUtils')) {
            return;
        }
        if (!\class_exists($search_class)) {
            $filename = \strtolower(\preg_replace(['/^DynamicOOO\\\\PluginUtilsV2\\\\/', '/([a-z])([A-Z])/', '/_/', '/\\\\/'], ['', '$1-$2', '-', \DIRECTORY_SEPARATOR], $search_class) ?? '');
            $filename = trailingslashit(__DIR__) . $filename . '.php';
            if (\is_readable($filename)) {
                include $filename;
            }
        }
    }
    /**
     * @param array<string,mixed> $config
     * @return self
     */
    public function set_config($config)
    {
        $required_keys = ['plugin_base', 'plugin_slug', 'version', 'plugin_file', 'plugin_name_underscored', 'license_url', 'prefix', 'product_unique_id', 'product_name_long', 'pricing_url'];
        foreach ($required_keys as $key) {
            if (!isset($config[$key])) {
                throw new \Exception("Missing required config key: {$key}");
            }
        }
        if (!isset($config['activation_advisor'])) {
            $config['activation_advisor'] = 'auto';
        }
        if (!isset($config['delay_init'])) {
            $config['delay_init'] = \false;
        }
        $this->config = $config;
        return $this;
    }
    /**
     * @param string $key
     * @return string
     */
    public function get_config($key = '')
    {
        return $this->config[$key] ?? '';
    }
    /**
     * @return array<string,array<string,string>>
     */
    public function get_action_links()
    {
        return $this->config['action_links'] ?? [];
    }
    /**
     * Enqueue admin styles
     * @return void
     */
    public function enqueue_admin_styles()
    {
        wp_enqueue_style($this->get_config('prefix') . '-admin-style', $this->assets->get_assets_url('css/admin-style.css'), [], $this->get_config('version'));
    }
}
