<?php

namespace DynamicOOO\PluginUtilsV2;

class PluginPage
{
    /**
     * @var Manager
     */
    protected $plugin_utils_manager;
    /**
     * @param Manager $plugin_utils_manager
     */
    public function __construct($plugin_utils_manager)
    {
        $this->plugin_utils_manager = $plugin_utils_manager;
        add_filter('plugin_row_meta', [$this, 'plugin_row_meta'], 10, 2);
        add_filter('plugin_action_links_' . $this->plugin_utils_manager->get_config('plugin_base'), [$this, 'plugin_action_links']);
    }
    /**
     * @param array<string,string> $plugin_meta
     * @param string $plugin_file
     * @return array<string,string>
     */
    public function plugin_row_meta($plugin_meta, $plugin_file)
    {
        if ($this->plugin_utils_manager->get_config('plugin_slug') . '/' . $this->plugin_utils_manager->get_config('plugin_slug') . '.php' === $plugin_file) {
            $row_meta = ['docs' => '<a href="https://help.dynamic.ooo/" aria-label="' . esc_attr(esc_html__('View Documentation', 'dynamic-content-for-elementor')) . '" target="_blank">' . esc_html__('Docs', 'dynamic-content-for-elementor') . '</a>', 'community' => '<a href="https://facebook.com/groups/dynamic.ooo" aria-label="' . esc_attr(esc_html__('Facebook Community', 'dynamic-content-for-elementor')) . '" target="_blank">' . esc_html__('FB Community', 'dynamic-content-for-elementor') . '</a>'];
            $plugin_meta = \array_merge($plugin_meta, $row_meta);
        }
        return $plugin_meta;
    }
    /**
     * @param array<string,string> $links
     * @return array<string,string>
     */
    public function plugin_action_links($links)
    {
        $action_links = $this->plugin_utils_manager->get_action_links();
        if (!empty($action_links)) {
            foreach ($action_links as $key => $link_data) {
                $links[$key] = \sprintf('<a title="%s" href="%s">%s</a>', esc_attr($link_data['label']), esc_url(admin_url($link_data['url'])), esc_html($link_data['label']));
            }
        }
        return $links;
    }
}
