<?php

namespace DynamicOOOS\TelegramBot\Api\Types;

use DynamicOOOS\TelegramBot\Api\BaseType;
use DynamicOOOS\TelegramBot\Api\TypeInterface;
class ChatPermissions extends BaseType implements TypeInterface
{
    /**
     * {@inheritdoc}
     *
     * @var array
     */
    protected static $requiredParams = [];
    /**
     * {@inheritdoc}
     *
     * @var array
     */
    protected static $map = ['can_send_messages' => \true, 'can_send_media_messages' => \true, 'can_send_polls' => \true, 'can_send_other_messages' => \true, 'can_add_web_page_previews' => \true, 'can_change_info' => \true, 'can_invite_users' => \true, 'can_pin_messages' => \true];
    /**
     * Optional. True, if the user is allowed to send text messages, contacts, locations and venues
     *
     * @var bool|null
     */
    protected $canSendMessages;
    /**
     * Optional. True, if the user is allowed to send audios, documents, photos, videos, video notes and voice notes,
     * implies can_send_messages
     *
     * @var bool|null
     */
    protected $canSendMediaMessages;
    /**
     * Optional. True, if the user is allowed to send polls, implies can_send_messages
     *
     * @var bool|null
     */
    protected $canSendPolls;
    /**
     * Optional. True, if the user is allowed to send animations, games, stickers and use inline bots, implies
     * can_send_media_messages
     *
     * @var bool|null
     */
    protected $canSendOtherMessages;
    /**
     * Optional. True, if the user is allowed to add web page previews to their messages, implies
     * can_send_media_messages
     *
     * @var bool|null
     */
    protected $canAddWebPagePreviews;
    /**
     * Optional. True, if the user is allowed to change the chat title, photo and other settings. Ignored in public
     * supergroups
     *
     * @var bool|null
     */
    protected $canChangeInfo;
    /**
     * Optional. True, if the user is allowed to invite new users to the chat
     *
     * @var bool|null
     */
    protected $canInviteUsers;
    /**
     * Optional. True, if the user is allowed to pin messages. Ignored in public supergroups
     *
     * @var bool|null
     */
    protected $canPinMessages;
    /**
     * @return bool|null
     */
    public function isCanSendMessages()
    {
        return $this->canSendMessages;
    }
    /**
     * @param bool $canSendMessages
     * @return void
     */
    public function setCanSendMessages($canSendMessages)
    {
        $this->canSendMessages = $canSendMessages;
    }
    /**
     * @return bool|null
     */
    public function isCanSendMediaMessages()
    {
        return $this->canSendMediaMessages;
    }
    /**
     * @param bool $canSendMediaMessages
     * @return void
     */
    public function setCanSendMediaMessages($canSendMediaMessages)
    {
        $this->canSendMediaMessages = $canSendMediaMessages;
    }
    /**
     * @return bool|null
     */
    public function isCanSendPolls()
    {
        return $this->canSendPolls;
    }
    /**
     * @param bool $canSendPolls
     * @return void
     */
    public function setCanSendPolls($canSendPolls)
    {
        $this->canSendPolls = $canSendPolls;
    }
    /**
     * @return bool|null
     */
    public function isCanSendOtherMessages()
    {
        return $this->canSendOtherMessages;
    }
    /**
     * @param bool $canSendOtherMessages
     * @return void
     */
    public function setCanSendOtherMessages($canSendOtherMessages)
    {
        $this->canSendOtherMessages = $canSendOtherMessages;
    }
    /**
     * @return bool|null
     */
    public function isCanAddWebPagePreviews()
    {
        return $this->canAddWebPagePreviews;
    }
    /**
     * @param bool $canAddWebPagePreviews
     * @return void
     */
    public function setCanAddWebPagePreviews($canAddWebPagePreviews)
    {
        $this->canAddWebPagePreviews = $canAddWebPagePreviews;
    }
    /**
     * @return bool|null
     */
    public function isCanChangeInfo()
    {
        return $this->canChangeInfo;
    }
    /**
     * @param bool $canChangeInfo
     * @return void
     */
    public function setCanChangeInfo($canChangeInfo)
    {
        $this->canChangeInfo = $canChangeInfo;
    }
    /**
     * @return bool|null
     */
    public function isCanInviteUsers()
    {
        return $this->canInviteUsers;
    }
    /**
     * @param bool $canInviteUsers
     * @return void
     */
    public function setCanInviteUsers($canInviteUsers)
    {
        $this->canInviteUsers = $canInviteUsers;
    }
    /**
     * @return bool|null
     */
    public function isCanPinMessages()
    {
        return $this->canPinMessages;
    }
    /**
     * @param bool $canPinMessages
     * @return void
     */
    public function setCanPinMessages($canPinMessages)
    {
        $this->canPinMessages = $canPinMessages;
    }
}
