<?php

namespace DynamicOOOS\TelegramBot\Api\Types;

use DynamicOOOS\TelegramBot\Api\BaseType;
use DynamicOOOS\TelegramBot\Api\TypeInterface;
/**
 * Class Contact
 * This object represents a phone contact.
 *
 * @package TelegramBot\Api\Types
 */
class Contact extends BaseType implements TypeInterface
{
    /**
     * {@inheritdoc}
     *
     * @var array
     */
    protected static $requiredParams = ['phone_number', 'first_name'];
    /**
     * {@inheritdoc}
     *
     * @var array
     */
    protected static $map = ['phone_number' => \true, 'first_name' => \true, 'last_name' => \true, 'user_id' => \true, 'vcard' => \true];
    /**
     * Contact's phone number
     *
     * @var string
     */
    protected $phoneNumber;
    /**
     * Contact's first name
     *
     * @var string
     */
    protected $firstName;
    /**
     * Optional. Contact's last name
     *
     * @var string|null
     */
    protected $lastName;
    /**
     * Optional. Contact's user identifier in Telegram
     *
     * @var int|null
     */
    protected $userId;
    /**
     * Optional. Additional data about the contact in the form of a vCard
     *
     * @var string|null
     */
    protected $vcard;
    /**
     * @return string
     */
    public function getFirstName()
    {
        return $this->firstName;
    }
    /**
     * @param string $firstName
     * @return void
     */
    public function setFirstName($firstName)
    {
        $this->firstName = $firstName;
    }
    /**
     * @return null|string
     */
    public function getLastName()
    {
        return $this->lastName;
    }
    /**
     * @param string $lastName
     * @return void
     */
    public function setLastName($lastName)
    {
        $this->lastName = $lastName;
    }
    /**
     * @return string
     */
    public function getPhoneNumber()
    {
        return $this->phoneNumber;
    }
    /**
     * @param string $phoneNumber
     * @return void
     */
    public function setPhoneNumber($phoneNumber)
    {
        $this->phoneNumber = $phoneNumber;
    }
    /**
     * @return int|null
     */
    public function getUserId()
    {
        return $this->userId;
    }
    /**
     * @param int $userId
     * @return void
     */
    public function setUserId($userId)
    {
        $this->userId = $userId;
    }
    /**
     * @return null|string
     */
    public function getVCard()
    {
        return $this->vcard;
    }
    /**
     * @param string $vcard
     * @return void
     */
    public function setVCard($vcard)
    {
        $this->vcard = $vcard;
    }
}
